Aisle
---

![type checked: mypy](https://img.shields.io/badge/mypy-type%20checked-green)
![coverage: 100](https://img.shields.io/badge/coverage-100%25-green)
[![import-linter](https://img.shields.io/badge/import%20linter-checked-green)](https://github.com/seddonym/import-linter)
[![ruff](https://img.shields.io/badge/style-ruff-41B5BE?style=flat)](https://github.com/astral-sh/ruff)
[![wemake-python-styleguide](https://img.shields.io/badge/style-wemake-000000.svg)](https://github.com/wemake-services/wemake-python-styleguide)

![python 3.12+](https://img.shields.io/badge/python-3.12+-blue)
[![License](https://img.shields.io/badge/license-GNU%20GPLv3-green)](./LICENSE)

[![test](https://github.com/Tapeline/Aisle/actions/workflows/test.yml/badge.svg?branch=master&event=push)](https://github.com/Tapeline/Aisle/actions/workflows/test.yml)
[![test](https://github.com/Tapeline/Aisle/actions/workflows/docs.yml/badge.svg?branch=master&event=push)](https://github.com/Tapeline/Aisle/actions/workflows/docs.yml)


Create C4 architecture diagrams of your project in no time.

---

<!-- TOC -->
  * [Description](#description)
  * [Installation](#installation)
  * [Usage](#usage)
  * [Planned features](#planned-features)
  * [Tech stack](#tech-stack)
  * [Developer](#developer)
  * [License](#license)
<!-- TOC -->

---

## Description

Aisle is a markup language and transpiling tool that aims to
be as simple and straightforward as possible when creating
architectural diagrams. Unlike other solutions it has very
simple and natural syntax, which makes it easier to start
and then understand your diagram.

## Installation

> Prerequisite: Python 3.12+, pip

```shell
pip install aisle
```

## Usage
Please refer to the [documentation](https://tapeline.github.io/Aisle/docs/)

## Planned features
- [ ] Styling
- [ ] Icons
- [ ] D2 as code generation target

## Tech stack
![python 3.12+](https://img.shields.io/badge/python-3.12+-blue)

## Developer
Project is being developed by [@Tapeline](https://github.com/Tapeline)

## License
This work is licensed under GNU General Public License v3.0
